/*
 * nzb
 *
 * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 * Authors:
 *   Mattias Nordstrom <matta at ftlight net>
 *
 * $Id: mainwindow.h,v 1.6 2005/10/03 19:04:55 mnordstr Exp $
 *   This file provides the GUI.
 */


#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QtGui>

#include "nzbdata.h"
#include "ui_mainwindow.h"
#include "downloader.h"
#include "decoder.h"
#include "output.h"

class QAction;
class QMenu;

class MainWindow : public QMainWindow,
                   public Ui::MainWindow
{
        Q_OBJECT
public:
        MainWindow( QWidget* parent = 0 );
        ~MainWindow();

        void loadFile(const QString &fileName);
        bool shuttingDown() const { return shutting_down; }
        QSettings* getConfig() { return config; }
        void setConfig(QSettings *config);
        QTableWidgetItem* getDownloaderItem(int thread_id) { return this->processes->item(thread_id, 0); }

public slots:
        void downloadEvent(QString message, int row, int type);
        void decodeEvent(QString message, int row, int type);
        void outputEvent(QString message, int type);

protected:
        void closeEvent(QCloseEvent *event);

private slots:
        void open();
        void about();
        void start();
        void stop();
        void pause();
        void resume();
        void stream();
        void options();
        void sortList();
        void clearList() { this->clearData(); }
        void restartDownloaders();
        void disableDownloadOfItems();
        void enableDownloadOfItems();

signals:
        void processDecoder();
        void processOutput();
        void processDownloader();
        void fullStop();
        void requestPause();
        void requestResume();

private:
        QSettings* loadSettings();
        void saveSettings();
        void clearData();
        void populateList();

        NzbList nzblist;
        QList<Downloader*> downloaders;
        Decoder *decoder;
        Output *output;

        QMutex file_lock;
        //QWaitCondition dc_done;

        QLabel *totalSpeed;
        QLabel *totalSize;
        QProgressBar *totalProgress;

        bool shutting_down;
        bool download_complete;

        QSettings *config;

};

#endif
