/*
 * nzb
 *
 * Copyright (C) 2004-2006 Mattias Nordstrom <matta at ftlight net>
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 *
 * Authors:
 *   Mattias Nordstrom <matta at ftlight net>
 *
 * $Id: optionsdlg.cpp,v 1.00 2005/10/16 12:03:32 mnordstr Exp $
 *   This file provides the Options Dialog.
 */


#include <QtGui>

#include "optionsdlg.h"
#include "mainwindow.h"

OptionsDlg::OptionsDlg(MainWindow *parent) : QDialog( parent )
{
        ui.setupUi(this);
        this->parent = parent;

        connect(ui.okButton, SIGNAL(clicked()), this, SLOT(accept()));
        connect(ui.cancelButton, SIGNAL(clicked()), this, SLOT(reject()));

        connect(ui.saveBrowse, SIGNAL(clicked()), this, SLOT(browseSave()));
        connect(ui.mediaBrowse, SIGNAL(clicked()), this, SLOT(browseMedia()));

        connect(ui.subfolders, SIGNAL(stateChanged(int)), this, SLOT(enableGuess(int)));
        connect(ui.use_file, SIGNAL(clicked()), this, SLOT(useFile()));

        QSettings *config = parent->getConfig();

        if (QFile::exists("nzb.ini")) {
                ui.use_file->setEnabled(false);
        }

        #ifndef Q_WS_WIN
        ui.use_file->setEnabled(false);
        #endif

        ui.host->setText(config->value("server/host").toString());
        ui.port->setText(config->value("server/port").toString());
        ui.username->setText(config->value("server/username").toString());
        ui.password->setText(config->value("server/password").toString());
        ui.connections->setValue(config->value("server/connections").toInt());

        if (config->value("server/auth").toBool()) {
                ui.auth->setCheckState(Qt::Checked);
        } else {
                ui.auth->setCheckState(Qt::Unchecked);
        }

        if (config->value("server/ssl").toBool()) {
                ui.ssl->setCheckState(Qt::Checked);
        } else {
                ui.ssl->setCheckState(Qt::Unchecked);
                ui.ssl_ignore_errors->setDisabled( true );
        }

        if (config->value("server/ssl_ignore_errors").toBool()) {
                ui.ssl_ignore_errors->setCheckState(Qt::Checked);
        } else {
                ui.ssl_ignore_errors->setCheckState(Qt::Unchecked);
        }

        if (config->value("list/autosort").toBool()) {
                ui.autosort->setCheckState(Qt::Checked);
        } else {
                ui.autosort->setCheckState(Qt::Unchecked);
        }

        if (config->value("list/hidecompleted").toBool()) {
                ui.hidecompleted->setCheckState(Qt::Checked);
        } else {
                ui.hidecompleted->setCheckState(Qt::Unchecked);
        }

        if (config->value("list/par_uncheck").toBool()) {
                ui.par_uncheck->setCheckState(Qt::Checked);
        } else {
                ui.par_uncheck->setCheckState(Qt::Unchecked);
        }

        ui.savepath->setText(config->value("output/savepath").toString());
        if (config->value("output/subfolders").toBool()) {
                ui.subfolders->setCheckState(Qt::Checked);
                ui.guessalbum->setEnabled(true);
        } else {
                ui.subfolders->setCheckState(Qt::Unchecked);
                ui.guessalbum->setEnabled(false);
        }
        if (config->value("output/guessalbum").toBool()) {
                ui.guessalbum->setCheckState(Qt::Checked);
        } else {
                ui.guessalbum->setCheckState(Qt::Unchecked);
        }
        ui.mediaplayer->setText(config->value("output/mediaplayer").toString());
        if (config->value("output/stream").toBool()) {
                ui.stream->setCheckState(Qt::Checked);
        } else {
                ui.stream->setCheckState(Qt::Unchecked);
        }

        connect(ui.ssl, SIGNAL(stateChanged(int)), this, SLOT(sslChange(int)));
}

void OptionsDlg::accept()
{
        QSettings *config = parent->getConfig();

        config->setValue("server/host", ui.host->text());
        config->setValue("server/port", ui.port->text().toInt());
        config->setValue("server/username", ui.username->text());
        config->setValue("server/password", ui.password->text());
        config->setValue("server/connections", ui.connections->value());
        config->setValue("server/auth", ((ui.auth->checkState() == Qt::Checked) ? true : false));
        config->setValue("server/ssl", ((ui.ssl->checkState() == Qt::Checked) ? true : false));
        config->setValue("server/ssl_ignore_errors", ((ui.ssl_ignore_errors->checkState() == Qt::Checked) ? true : false));

        config->setValue("list/autosort", ((ui.autosort->checkState() == Qt::Checked) ? true : false));
        config->setValue("list/hidecompleted", ((ui.hidecompleted->checkState() == Qt::Checked) ? true : false));
        config->setValue("list/par_uncheck", ((ui.par_uncheck->checkState() == Qt::Checked) ? true : false));

        config->setValue("output/savepath", ui.savepath->text());
        config->setValue("output/subfolders", ((ui.subfolders->checkState() == Qt::Checked) ? true : false));
        config->setValue("output/guessalbum", ((ui.guessalbum->checkState() == Qt::Checked) ? true : false));
        config->setValue("output/mediaplayer", ui.mediaplayer->text());
        config->setValue("output/stream", ((ui.stream->checkState() == Qt::Checked) ? true : false));

        config->sync();

        QDialog::accept();
}

void OptionsDlg::reject()
{
        QDialog::reject();
}

void OptionsDlg::browseSave()
{
        QString dir = QFileDialog::getExistingDirectory(this, "Choose a save directory", "", QFileDialog::DontResolveSymlinks);
        if (dir != "") {
                ui.savepath->setText(dir);
        }
}

void OptionsDlg::browseMedia()
{
        #ifdef WIN32
        QString dir = QFileDialog::getOpenFileName(this, "Choose media player", "", "Executables (*.exe);;All Files (*)");
        #else
        QString dir = QFileDialog::getOpenFileName(this, "Choose media player", "", "All Files (*)");
        #endif
        if (dir != "") {
                ui.mediaplayer->setText("\""+dir+"\"");
        }
}

void OptionsDlg::enableGuess(int state)
{
        if (state == Qt::Checked) {
                ui.guessalbum->setEnabled(true);
        } else {
                ui.guessalbum->setEnabled(false);
        }
}

void OptionsDlg::sslChange(int state)
{
        if (state == Qt::Checked) {
                ui.port->setText("563");
        } else {
                ui.port->setText("119");
        }
}

void OptionsDlg::useFile()
{
        QSettings *config = new QSettings("nzb.ini", QSettings::IniFormat);
        parent->setConfig(config);
        config->sync();
        ui.use_file->setEnabled(false);
}
